@@ -29,6 +29,7 @@ import Data.Either.Extra
 import Data.Foldable (toList)
 import Data.List.Extra
 import Data.List.NonEmpty (NonEmpty)
+import qualified Data.HashSet as Set
 import Data.Maybe
 import Data.Data
 import Data.Semigroup
@@ -294,7 +295,7 @@ commandExplicitAction oparams = do
             let cwd = listToMaybe $ reverse [x | Cwd x <- opts]
             putVerbose $
                 maybe "" (\x -> "cd " ++ x ++ "; ") cwd ++
-                last (showCommandForUser2 prog args : [x | UserCommand x <- opts])
+                lastDef (showCommandForUser2 prog args) [x | UserCommand x <- opts]
             verb <- getVerbosity
             -- run quietly to suppress the tracer (don't want to print twice)
             (if verb >= Verbose then quietly else id) act
@@ -311,8 +312,10 @@ commandExplicitAction oparams = do
             | otherwise = act params
 
         autodeps act = do
-            ResultFSATrace pxs : res <- act params{opts = addFSAOptions "r" opts, results = ResultFSATrace [] : results}
-            xs <- liftIO $ filterM doesFileExist [x | FSARead x <- pxs]
+            ResultFSATrace pxs : res <- act params{opts = addFSAOptions "rwm" opts, results = ResultFSATrace [] : results}
+            let written = Set.fromList $ [x | FSAMove x _ <- pxs] ++ [x | FSAWrite x <- pxs]
+            -- If something both reads and writes to a file, it isn't eligible to be an autodeps
+            xs <- liftIO $ filterM doesFileExist [x | FSARead x <- pxs, not $ x `Set.member` written]
             cwd <- liftIO getCurrentDirectory
             temp <- fixPaths cwd xs
             unsafeAllowApply $ need temp
