@@ -354,9 +354,9 @@ recordRoot step locals (doubleToFloat -> end) db = runLocked db $ do
             {result = (newValue (), BS.empty)
             ,changed = step
             ,built = step
-            ,depends = nubDepends $ reverse $ localDepends local
+            ,depends = flattenDepends $ localDepends local
             ,execution = 0
-            ,traces = reverse $ Trace BS.empty end end : localTraces local}
+            ,traces = flattenTraces $ addTrace (localTraces local) $ Trace BS.empty end end}
     setMem db rootId rootKey $ Ready rootRes
     liftIO $ setDisk db rootId rootKey $ Loaded $ fmap snd rootRes
 
