@@ -17,7 +17,7 @@ import Data.List(foldl')
 data Intern a = Intern {-# UNPACK #-} !Word32 !(Map.HashMap a Id)
 
 newtype Id = Id Word32
-    deriving (Eq,Hashable,Binary,Show,NFData,Storable)
+    deriving (Eq,Hashable,Ord,Binary,Show,NFData,Storable)
 
 empty :: Intern a
 empty = Intern 0 Map.empty
@@ -33,11 +33,11 @@ add k (Intern v mp) = (Intern v2 $ Map.insert k (Id v2) mp, Id v2)
 
 
 lookup :: (Eq a, Hashable a) => a -> Intern a -> Maybe Id
-lookup k (Intern n mp) = Map.lookup k mp
+lookup k (Intern _ mp) = Map.lookup k mp
 
 
 toList :: Intern a -> [(a, Id)]
-toList (Intern a b) = Map.toList b
+toList (Intern _ mp) = Map.toList mp
 
 
 fromList :: (Eq a, Hashable a) => [(a, Id)] -> Intern a
