@@ -3,7 +3,7 @@ module Test.Resources(main) where
 
 import Development.Shake
 import Test.Type
-import Data.List
+import Data.List.Extra
 import System.FilePath
 import Control.Exception.Extra
 import System.Time.Extra
@@ -11,7 +11,7 @@ import Control.Monad
 import Data.IORef
 
 
-main = shakeTest_ test $ do
+main = testBuild test $ do
     -- test I have good Ord and Show
     do
         r1 <- newResource "test" 2
@@ -56,7 +56,7 @@ main = shakeTest_ test $ do
         res <- newThrottle "throttle" 2 0.4
         phony "throttle" $ need ["t_file1.1","t_file2.1","t_file3.2","t_file4.1","t_file5.2"]
         "t_*.*" %> \out -> do
-            withResource res (read $ drop 1 $ takeExtension out) $
+            withResource res (read $ drop1 $ takeExtension out) $
                 when (takeBaseName out == "t_file3") $ liftIO $ sleep 0.2
             writeFile' out ""
 
@@ -74,5 +74,5 @@ test build = do
             (s, _) <- duration $ build [flags,"throttle","--no-report","--clean"]
             -- the 0.1s cap is a guess at an upper bound for how long everything else should take
             -- and should be raised on slower machines
-            assertBool (s >= 1.4 && s < 1.6) $
-                "Bad throttling, expected to take 1.4s + computation time (cap of 0.2s), took " ++ show s ++ "s"
+            assertBool (s >= 1.4 && s < 1.8) $
+                "Bad throttling, expected to take 1.4s + computation time (cap of 0.4s), took " ++ show s ++ "s"
