@@ -18,7 +18,8 @@ newtype GhcFlags = GhcFlags () deriving (Show,Typeable,Eq,Hashable,Binary,NFData
 type instance RuleResult GhcPkg = [String]
 type instance RuleResult GhcFlags = [String]
 
-main = testBuild (notWindowsCI . defaultTest) $ do
+-- Doesn't work on CI, seems self-building under `cabal test` is just hard
+main = testBuild (notCI . defaultTest) $ do
     want ["Main" <.> exe]
 
     ghcPkg <- addOracleHash $ \GhcPkg{} -> do
@@ -45,7 +46,7 @@ main = testBuild (notWindowsCI . defaultTest) $ do
 
         trackAllow ["**/*.o","**/*.hi","Makefile"]
         ghc $ ["-M",run] ++ flags
-        need . filter (\x -> takeExtension x == ".hs") . concatMap snd . parseMakefile =<< liftIO (readFile "Makefile")
+        need . concatMap (filter (\x -> takeExtension x == ".hs") . snd) . parseMakefile =<< liftIO (readFile "Makefile")
         ghc $ ["-o",out,run,"-j4"] ++ flags
 
     ".pkgs" %> \out -> do
