@@ -4,7 +4,7 @@ module Test.Type(
     sleep, sleepFileTime, sleepFileTimeCalibrate,
     testBuildArgs, testBuild, testSimple, testNone,
     shakeRoot,
-    defaultTest, hasTracker,
+    defaultTest, hasTracker, notCI, notWindowsCI, notMacCI,
     copyDirectoryChanged, copyFileChangedIO,
     assertWithin,
     assertBool, assertBoolIO, assertException, assertExceptionAfter,
@@ -39,6 +39,7 @@ import System.Random
 import General.GetOpt
 import System.IO.Extra as IO
 import System.Time.Extra
+import System.Info.Extra
 
 
 testBuildArgs
@@ -151,7 +152,22 @@ shakeRoot = "../.."
 tracker :: IO Lint
 tracker = do
     fsatrace <- findExecutable $ "fsatrace" <.> exe
-    pure $ if isJust fsatrace then LintFSATrace else LintBasic
+    -- Tracking on a Mac is pretty unreliable
+    pure $ if not isMac && isJust fsatrace then LintFSATrace else LintBasic
+
+-- Tests that don't currently work on CI
+notCI :: IO () -> IO ()
+notCI act = do
+    b <- lookupEnv "CI"
+    when (isNothing b) act
+
+-- Tests that don't currently work on Windows CI
+notWindowsCI :: IO () -> IO ()
+notWindowsCI = if isWindows then notCI else id
+
+-- Tests that don't currently work on Mac CI
+notMacCI :: IO () -> IO ()
+notMacCI = if isMac then notCI else id
 
 hasTracker :: IO Bool
 hasTracker = do
