@@ -5,33 +5,33 @@ import Development.Shake
 import Test.Type
 
 
-main = shakeTest_ test $ do
+main = testBuild test $ do
     "in.txt" %> \out -> do
         a <- getVerbosity
-        b <- withVerbosity Normal getVerbosity
+        b <- withVerbosity Info getVerbosity
         writeFile' out $ unwords $ map show [a,b]
 
     "out.txt" %> \out -> do
         x <- getVerbosity
-        ys <- withVerbosity Loud $ do
+        ys <- withVerbosity Verbose $ do
             a <- getVerbosity
             need ["in.txt"] -- make sure the inherited verbosity does not get passed along
             b <- getVerbosity
             c <- quietly getVerbosity
             d <- fmap shakeVerbosity getShakeOptions
-            return [a,b,c,d]
+            pure [a,b,c,d]
         z <- getVerbosity
         writeFile' out $ unwords $ map show $ [x] ++ ys ++ [z]
 
 test build = do
     build ["out.txt","--clean"]
-    assertContents "in.txt" "Normal Normal"
-    assertContents "out.txt" "Normal Loud Loud Quiet Normal Normal"
+    assertContents "in.txt" "Info Info"
+    assertContents "out.txt" "Info Verbose Verbose Error Info Info"
 
     build ["out.txt","--clean","--verbose"]
-    assertContents "in.txt" "Loud Normal"
-    assertContents "out.txt" "Loud Loud Loud Quiet Loud Loud"
+    assertContents "in.txt" "Verbose Info"
+    assertContents "out.txt" "Verbose Verbose Verbose Error Verbose Verbose"
 
     build ["out.txt","--clean","--quiet"]
-    assertContents "in.txt" "Quiet Normal"
-    assertContents "out.txt" "Quiet Loud Loud Quiet Quiet Quiet"
+    assertContents "in.txt" "Warn Info"
+    assertContents "out.txt" "Warn Verbose Verbose Error Warn Warn"
